            _     _                              _
     __   _(_) __| | ___  ___        _ __  _   _| | _____ _ __
     \ \ / / |/ _` |/ _ \/ _ \ _____| '_ \| | | | |/ / _ \ '__|
      \ V /| | (_| |  __/ (_) |_____| |_) | |_| |   <  __/ |
       \_/ |_|\__,_|\___|\___/      | .__/ \__, |_|\_\___|_|
                                    |_|    |___/

[![PyPI version](https://badge.fury.io/py/video-pyker.svg)](https://badge.fury.io/py/video-pyker)

## About

A little terminal game for Jacks-or-Better [Video Poker](https://www.pokerlistings.com/casino-rules-video-poker#:~:text=Rules%20of%20Video%20Poker). Written in Python.

## How to run

Install the package with pip:

```console
pip install video-pyker
```

Run the game as a script

```console
video-pyker
```

or as a module

```console
python -m video_pyker
```

## Notes

- Requires python version 3.10.2+

## LICENSE

MIT @ Charlie Morris
